@@ -1,28 +1,24 @@
 #ifndef STAN_MCMC_HMC_HAMILTONIANS_DENSE_E_METRIC_HPP
 #define STAN_MCMC_HMC_HAMILTONIANS_DENSE_E_METRIC_HPP
 
-#include <boost/random/variate_generator.hpp>
-#include <boost/random/normal_distribution.hpp>
-
 #include <stan/math/prim/mat/fun/Eigen.hpp>
-#include <Eigen/Cholesky>
-
 #include <stan/math/prim/mat/meta/index_type.hpp>
 #include <stan/mcmc/hmc/hamiltonians/base_hamiltonian.hpp>
 #include <stan/mcmc/hmc/hamiltonians/dense_e_point.hpp>
+#include <boost/random/variate_generator.hpp>
+#include <boost/random/normal_distribution.hpp>
+#include <Eigen/Cholesky>
 
 namespace stan {
   namespace mcmc {
 
     // Euclidean manifold with dense metric
-    template <typename Model, typename BaseRNG>
+    template <class Model, class BaseRNG>
     class dense_e_metric
       : public base_hamiltonian<Model, dense_e_point, BaseRNG> {
     public:
-      dense_e_metric(Model& model, std::ostream* e)
-        : base_hamiltonian<Model, dense_e_point, BaseRNG>(model, e) {}
-
-      ~dense_e_metric() {}
+      explicit dense_e_metric(const Model& model)
+        : base_hamiltonian<Model, dense_e_point, BaseRNG>(model) {}
 
       double T(dense_e_point& z) {
         return 0.5 * z.p.transpose() * z.mInv * z.p;
@@ -36,15 +32,27 @@ namespace stan {
         return this->V(z);
       }
 
-      const Eigen::VectorXd dtau_dq(dense_e_point& z) {
+      double dG_dt(dense_e_point& z,
+                   interface_callbacks::writer::base_writer& info_writer,
+                   interface_callbacks::writer::base_writer& error_writer) {
+        return 2 * T(z) - z.q.dot(z.g);
+      }
+
+      Eigen::VectorXd dtau_dq(
+        dense_e_point& z,
+        interface_callbacks::writer::base_writer& info_writer,
+        interface_callbacks::writer::base_writer& error_writer) {
         return Eigen::VectorXd::Zero(this->model_.num_params_r());
       }
 
-      const Eigen::VectorXd dtau_dp(dense_e_point& z) {
+      Eigen::VectorXd dtau_dp(dense_e_point& z) {
         return z.mInv * z.p;
       }
 
-      const Eigen::VectorXd dphi_dq(dense_e_point& z) {
+      Eigen::VectorXd dphi_dq(
+        dense_e_point& z,
+        interface_callbacks::writer::base_writer& info_writer,
+        interface_callbacks::writer::base_writer& error_writer) {
         return z.g;
       }
 
