@@ -11,7 +11,9 @@ namespace stan {
   namespace mcmc {
     using Eigen::Dynamic;
 
-    // Point in a generic phase space
+    /**
+     * Point in a generic phase space
+     */
     class ps_point {
       friend class ps_point_test;
 
@@ -71,9 +73,7 @@ namespace stan {
        * @param writer writer callback
        */
       virtual void
-      write_metric(stan::interface_callbacks::writer::base_writer& writer) {
-        writer("# No free parameters for unit metric");
-      }
+      write_metric(stan::interface_callbacks::writer::base_writer& writer) {}
 
     protected:
       template <typename T>
