@@ -4,19 +4,22 @@
 #include <stan/mcmc/hmc/hamiltonians/ps_point.hpp>
 
 namespace stan {
-
   namespace mcmc {
-
-    // Point in a phase space with a base
-    // Euclidean manifold with unit metric
+    /**
+     * Point in a phase space with a base
+     * Euclidean manifold with unit metric
+     */
     class unit_e_point: public ps_point {
     public:
       explicit unit_e_point(int n)
         : ps_point(n) {}
     };
 
-  }  // mcmc
+    void write_metric(stan::interface_callbacks::writer::base_writer& writer) {
+      writer("No free parameters for unit metric");
+    }
 
+  }  // mcmc
 }  // stan
 
 #endif
