@@ -19,9 +19,10 @@ namespace stan {
     public:
       typedef Eigen::Matrix<Scalar, DimAtCompile, 1> VectorT;
       typedef Eigen::Matrix<Scalar, DimAtCompile, DimAtCompile> HessianT;
+      // NOLINTNEXTLINE(build/include_what_you_use)
       typedef boost::tuple<Scalar, VectorT, VectorT> UpdateT;
 
-      LBFGSUpdate(size_t L = 5) : _buf(L) {}
+      explicit LBFGSUpdate(size_t L = 5) : _buf(L) {}
 
       /**
        * Set the number of inverse Hessian updates to keep.
