@@ -17,8 +17,12 @@ namespace stan {
       using boost::math::digamma;
 
       T falling_fact(falling_factorial(x.val_, n.val_));
-      return fvar<T>(falling_fact, falling_fact * digamma(x.val_ + 1) * x.d_
-                     - falling_fact * digamma(n.val_ + 1) * n.d_);
+      return fvar<T>(falling_fact,
+                     falling_fact
+                     * (digamma(x.val_ + 1) - digamma(x.val_ - n.val_ + 1))
+                     * x.d_
+                     + falling_fact
+                     * digamma(x.val_ - n.val_ + 1) * n.d_);
     }
 
     template<typename T>
@@ -29,7 +33,9 @@ namespace stan {
 
       T falling_fact(falling_factorial(x.val_, n));
       return fvar<T>(falling_fact,
-                     falling_fact * digamma(x.val_ + 1) * x.d_);
+                     falling_fact
+                     * (digamma(x.val_ + 1) - digamma(x.val_ - n + 1))
+                     * x.d_);
     }
 
     template<typename T>
@@ -40,7 +46,8 @@ namespace stan {
 
       T falling_fact(falling_factorial(x, n.val_));
       return fvar<T>(falling_fact,
-                     -falling_fact * digamma(n.val_ + 1) * n.d_);
+                     falling_fact
+                     * digamma(x - n.val_ + 1) * n.d_);
     }
   }
 }
