@@ -9,7 +9,7 @@
 namespace stan {
   namespace math {
 
-    /** \addtogroup csr_format 
+    /** \addtogroup csr_format
      *  @{
      */
 
@@ -21,7 +21,7 @@ namespace stan {
      * @param[in] i Index into resulting z vector.
      * @return z[i] where z is conversion from u.
      */
-    int csr_u_to_z(const std::vector<int>& u, int i) {
+    inline int csr_u_to_z(const std::vector<int>& u, int i) {
       check_positive("csr_u_to_z", "u.size()", u.size());
       check_range("csr_u_to_z", "i", u.size(), i + 1, "index out of range");
       return u[i + 1] - u[i];
