@@ -54,10 +54,8 @@ namespace stan {
 
       // Compute vectorized cdf_log and gradient
       using stan::math::value_of;
-      using stan::math::gamma_q;
-      using boost::math::tgamma;
-      using std::exp;
-      using std::pow;
+      using boost::math::gamma_q;
+      using boost::math::lgamma;
       using std::log;
       using std::exp;
 
@@ -78,13 +76,13 @@ namespace stan {
 
         const T_partials_return n_dbl = value_of(n_vec[i]);
         const T_partials_return lambda_dbl = value_of(lambda_vec[i]);
-        const T_partials_return Pi = gamma_q(n_dbl+1, lambda_dbl);
+        const T_partials_return log_Pi = log(gamma_q(n_dbl+1, lambda_dbl));
 
-        P += log(Pi);
+        P += log_Pi;
 
         if (!is_constant_struct<T_rate>::value)
-          operands_and_partials.d_x1[i] -= exp(-lambda_dbl)
-            * pow(lambda_dbl, n_dbl) / tgamma(n_dbl+1) / Pi;
+          operands_and_partials.d_x1[i] += - exp(n_dbl * log(lambda_dbl)
+            - lambda_dbl - lgamma(n_dbl+1) - log_Pi);
       }
 
       return operands_and_partials.value(P);
